==> mongodb-5.0.30.gh.tar.gz: mongo-r5.0.30/src/mongo/db/storage/storage_stats.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/bson/bsonobj.h"

namespace mongo {

/**
 * Manages statistics from the storage engine, allowing addition of statistics and serialization to
 * BSON.
 */
class StorageStats {
public:
    // This is a pure virtual class, so the constructors will never be called directly, and slicing
    // should not be an issue.
    StorageStats() = default;
    StorageStats(const StorageStats&) = default;
    StorageStats(StorageStats&&) = default;

    StorageStats& operator=(const StorageStats&) = delete;
    StorageStats& operator=(StorageStats&&) = delete;

    virtual ~StorageStats() = default;

    virtual BSONObj toBSON() const = 0;

    virtual std::unique_ptr<StorageStats> clone() const = 0;

    virtual StorageStats& operator+=(const StorageStats&) = 0;
    virtual StorageStats& operator-=(const StorageStats&) = 0;
};

}  // namespace mongo

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/db/storage/storage_stats.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/bson/bsonobj.h"

namespace mongo {

/**
 * Manages statistics from the storage engine, allowing addition of statistics, serialization to
 * BSON, and access to certain metrics.
 */
class StorageStats {
public:
    // This is a pure virtual class, so the constructors will never be called directly, and slicing
    // should not be an issue.
    StorageStats() = default;
    StorageStats(const StorageStats&) = default;
    StorageStats(StorageStats&&) = default;

    StorageStats& operator=(const StorageStats&) = delete;
    StorageStats& operator=(StorageStats&&) = delete;

    virtual ~StorageStats() = default;

    virtual BSONObj toBSON() const = 0;

    virtual uint64_t bytesRead() const = 0;
    virtual Microseconds readingTime() const = 0;

    virtual std::unique_ptr<StorageStats> clone() const = 0;

    virtual StorageStats& operator+=(const StorageStats&) = 0;
    virtual StorageStats& operator-=(const StorageStats&) = 0;
};

}  // namespace mongo
